@@ -29,8 +29,18 @@ Example::
 
     from path import Path
     d = Path('/home/guido/bin')
+
+    # Globbing
     for f in d.files('*.py'):
         f.chmod(0o755)
+
+    # Changing the working directory:
+    with Path("somewhere"):
+        # cwd in now `somewhere`
+        ...
+
+    # Concatenate paths with /
+    foo_txt = Path("bar") / "foo.txt"
 """
 
 from __future__ import unicode_literals
@@ -84,6 +94,7 @@ if PY2:
     text_type = __builtin__.unicode
     getcwdu = os.getcwdu
     map = itertools.imap
+    FileNotFoundError = OSError
 
 
 @contextlib.contextmanager
@@ -100,7 +111,7 @@ def io_error_compat():
 ##############################################################################
 
 
-__all__ = ['Path', 'CaseInsensitivePattern']
+__all__ = ['Path', 'TempDir', 'CaseInsensitivePattern']
 
 
 LINESEPS = ['\r\n', '\r', '\n']
@@ -112,8 +123,8 @@ U_NL_END = re.compile(r'(?:{0})$'.format(U_NEWLINE.pattern))
 
 
 try:
-    import pkg_resources
-    __version__ = pkg_resources.require('path.py')[0].version
+    import importlib_metadata
+    __version__ = importlib_metadata.version('path.py')
 except Exception:
     __version__ = 'unknown'
 
@@ -739,10 +750,32 @@ class Path(text_type):
         of all the files users have in their :file:`bin` directories.
 
         .. seealso:: :func:`glob.glob`
+
+        .. note:: Glob is **not** recursive, even when using ``**``.
+                  To do recursive globbing see :func:`walk`,
+                  :func:`walkdirs` or :func:`walkfiles`.
         """
         cls = self._next_class
         return [cls(s) for s in glob.glob(self / pattern)]
 
+    def iglob(self, pattern):
+        """ Return an iterator of Path objects that match the pattern.
+
+        `pattern` - a path relative to this directory, with wildcards.
+
+        For example, ``Path('/users').iglob('*/bin/*')`` returns an
+        iterator of all the files users have in their :file:`bin`
+        directories.
+
+        .. seealso:: :func:`glob.iglob`
+
+        .. note:: Glob is **not** recursive, even when using ``**``.
+                  To do recursive globbing see :func:`walk`,
+                  :func:`walkdirs` or :func:`walkfiles`.
+        """
+        cls = self._next_class
+        return (cls(s) for s in glob.iglob(self / pattern))
+
     #
     # --- Reading or writing an entire file at once.
 
@@ -1289,9 +1322,8 @@ class Path(text_type):
         file does not exist. """
         try:
             self.unlink()
-        except OSError:
-            _, e, _ = sys.exc_info()
-            if e.errno != errno.ENOENT:
+        except FileNotFoundError as exc:
+            if PY2 and exc.errno != errno.ENOENT:
                 raise
         return self
 
@@ -1400,7 +1432,7 @@ class Path(text_type):
         is not capable of storing a copy of the entire source tree.
         """
         update = kwargs.pop('update', False)
-        with tempdir() as _temp_dir:
+        with TempDir() as _temp_dir:
             # first copy the tree to a stage directory to support
             #  the parameters and behavior of copytree.
             stage = _temp_dir / str(hash(self))
@@ -1615,15 +1647,15 @@ class Multi:
         )
 
 
-class tempdir(Path):
+class TempDir(Path):
     """
     A temporary directory via :func:`tempfile.mkdtemp`, and
     constructed with the same parameters that you can use
     as a context manager.
 
-    Example:
+    Example::
 
-        with tempdir() as d:
+        with TempDir() as d:
             # do stuff with the Path object "d"
 
         # here the directory is deleted automatically
@@ -1638,19 +1670,27 @@ class tempdir(Path):
 
     def __new__(cls, *args, **kwargs):
         dirname = tempfile.mkdtemp(*args, **kwargs)
-        return super(tempdir, cls).__new__(cls, dirname)
+        return super(TempDir, cls).__new__(cls, dirname)
 
     def __init__(self, *args, **kwargs):
         pass
 
     def __enter__(self):
-        return self
+        # TempDir should return a Path version of itself and not itself
+        # so that a second context manager does not create a second
+        # temporary directory, but rather changes CWD to the location
+        # of the temporary directory.
+        return self._next_class(self)
 
     def __exit__(self, exc_type, exc_value, traceback):
         if not exc_value:
             self.rmtree()
 
 
+# For backwards compatibility.
+tempdir = TempDir
+
+
 def _multi_permission_mask(mode):
     """
     Support multiple, comma-separated Unix chmod symbolic modes.
